Template Tags and Filters — django-icons 0.1.0 documentation

# Template Tags and Filters

Note

To use these template tags, you should have already loaded the `icons` template tag library, and made sure that the necessary media for the icons is available to your template (e.g. the FontAwesome CSS). Read the Installation and Quickstart sections on how to accomplish this.

## icon

`django_icons.templatetags.icons.` `icon`(name, *args, **kwargs)

  Render an icon

  Parameters:

  > name
  >   The name of the icon to be rendered
  > title

  >   The title attribute for the icon

  >   default: | None (no title attribute rendered)

  > renderer

  >   The renderer to use for the icon

  >   default: | The default renderer as per `settings.py`, or ultimately FontAwesomeRenderer.

  Usage:

      icon(name)

  Example:

      icon('pencil')
      icon('trash', title='Delete')